 %  Matlab script for visualization of location uncertainties, computed by program "LOCERR (by J.Malek)"
 %  Author of the visualisation script: Miriam Kristekova, 2015 (kristekova@savba.sk)
 %                                      Geophysical Institute of Slovak Academy of Sciencies, 
 %                                      Bratislava, Slovakia
  
 % input files needed: - ascii files containing coordinates of stations (all and the used ones)
 %                     - output files of LOCCER program containing uncertainties in X, Y, Z direction
 %                       (X???.txt, Y???.txt, Z???.txt)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
clear all;  
        
%-----------  SET DEPTH of source and the DIMENSIONS of the area in km -------
depth = '004';     % //// EDIT and set to an appropriate value
N_xy = 100;		   % //// EDIT and set to an appropriate value
%-----------------------------------------------------------------------------

cmap=colormap(jet(100));
cmap=flipud(cmap);                         
colormap(cmap);

%----- //// EDIT and set to an appropriate file names here //// ------
%  
load stat_coord_23.txt;  % file containing coordinates of all stations (including unused ones - black triangles in Figs)
load stat_coord_16.txt;  % file containing only coordinates of stations used to compute uncertainties(white triangles in Figs)
%---------------------------------------------------------------------

load_Z = ['load Z', depth,'.txt' ]; % input file containing uncertainties in Z direction (output of "LOCERR")
load_Y = ['load Y', depth,'.txt' ]; % input file containing uncertainties in Y direction (output of "LOCERR")
load_X = ['load X', depth,'.txt' ]; % input file containing uncertainties in X direction (output of "LOCERR")

eval(load_Z);
eval(load_Y);
eval(load_X);
text_figure1  = ['depth ',depth,' km, ', 'depth error'];
text_figure2  = ['depth ',depth,' km, ', 'epicentral error'];


for i=1:1:N_xy;       
    for j=1:1:N_xy;   
                                      
        Z = ['Z',depth,'n(j,i) = Z',depth,'(i+(j-1)*100.,3);'];     
        eval(Z);

        Y = ['Y',depth,'n(j,i) = Y',depth,'(i+(j-1)*100.,3);']; 
        eval(Y);

        X = ['X',depth,'n(j,i) = X',depth,'(i+(j-1)*100.,3);']; 
        eval(X);
    end
end

Q_EP_ERR = eval (['(X',depth,'n.*X',depth,'n) + (Y',depth,'n.*Y',depth,'n)']);      
EP_ERR = realsqrt(Q_EP_ERR);
TOT_ERR = eval (['(realsqrt((X',depth,'n.*X',depth,'n) + (Y',depth,'n.*Y',depth,'n) + (Z',depth,'n.*Z',depth,'n)))']);  


%===============Plotting Figures============================
% --------------DEPTH ERROR---------------------------------
% -> pcolor flat
%----------------
% figure;
eval (['pcolor (0:1:99, 0:1:99,Z',depth,'n)']);
shading flat;
caxis([0 5]);
colormap(cmap);
colorbar;
title(text_figure1,'FontSize',14,'FontAngle','italic');

% -> adding contours:
%----------------------------------------------
hold on;  
eval (['[C,h]=contour (0:1:99, 0:1:99,Z',depth,'n,20);']);
set(h,'LineStyle','-', 'Color','k' );
set(h,'LevelList',[0.25 0.5 0.75 1. 1.25 1.5 1.75 2.0 2.25 2.5 2.75 3.0 3.25 3.5 3.75 4.0 4.25 4.5 4.75 5.0],...
 'TextList',[0.25 0.5 0.75 1. 1.25 1.5 1.75 2.0 2.25 2.5 2.75 3.0 3.25 3.5 3.75 4.0 4.25 4.5 4.75 5.0]);
% 'TextStep',2);
clabel(C,h);

% PLEASE NOTE: in a plot command below, there is made correction of shift between coordinates of stations in our input files "stat_coord_??" and coordinates of stations used in computations inside LOCCER program (+8 and -24). When setting proper coordinates directly in both input files you will not need to use this correction.%
 
% plotting all stations-black triangles 
%----- //// EDIT and set to an appropriate file name (with coordinates of all stations) here //// ------
plot (stat_coord_23(:,2)+8.,stat_coord_23(:,1)-24,'^',...      
                'MarkerEdgeColor','k',...
                'MarkerFaceColor','k',...
                'MarkerSize',10);

% plotting stations used-white triangles
%----- //// EDIT and set to an appropriate file name (with coordinates of stations used) here //// ------
plot (stat_coord_16(:,2)+8.,stat_coord_16(:,1)-24,'^',...      
                'MarkerEdgeColor','k',...
                'MarkerFaceColor','w',...
                'MarkerSize',10);
print('-f','-dpng','-r300',['Z_err',depth,'_flat_cont_STkorig_sel_all.png']);

% --------------EPICENTRAL ERROR-----------------------------------------
% -> pcolor flat
%----------------
figure;
% eval (['pcolor (0:1:99, 0:1:99,Y',depth,'n)']);
pcolor (0:1:99, 0:1:99, EP_ERR);
shading flat;
caxis([0 5]);                                                  
colormap(cmap);
colorbar;
title(text_figure2,'FontSize',14,'FontAngle','italic');
% print('-f','-dpng','-r300',['EP_err',depth,'_flat_TEST.png'])
%----------------------------------------------
% -> adding contours:
hold on;
[C,h]=contour (0:1:99, 0:1:99,EP_ERR,19);
set(h,'LineStyle','-', 'Color','k' );
set(h,'LevelList',[0.1 0.2 0.25 0.5 0.75 1. 1.25 1.5 1.75 2.0 2.25 2.5 2.75 3.0 3.25 3.5 3.75 4.0 4.25 4.5 4.75 5.0],...
 'TextList',[0.1 0.2 0.25 0.5 0.75 1. 1.25 1.5 1.75 2.0 2.25 2.5 2.75 3.0 3.25 3.5 3.75 4.0 4.25 4.5 4.75 5.0])
% 'TextStep',2);
clabel(C,h);

% PLEASE NOTE: in a plot command below, there is made correction of shift between coordinates of stations in our input files "stat_coord_??" and coordinates of stations used in computations inside LOCCER program (+8 and -24). When setting proper coordinates directly in both input files you will not need to use this correction.%
 
 % plotting all stations-black triangles
%----- //// EDIT and set to an appropriate file name (with coordinates of all stations) here //// ------
plot (stat_coord_23(:,2)+8.,stat_coord_23(:,1)-24,'^',...      
                'MarkerEdgeColor','k',...
                'MarkerFaceColor','k',...
                'MarkerSize',10);

% plotting stations used-white triangles
%----- //// EDIT and set to an appropriate file name (with coordinates of stations used) here //// ------
plot (stat_coord_16(:,2)+8.,stat_coord_16(:,1)-24,'^',...      
                'MarkerEdgeColor','k',...
                'MarkerFaceColor','w',...
                'MarkerSize',10);
print('-f','-dpng','-r300',['EP_err',depth,'_flat_cont_STkorig_sel_all.png']);
      
    